@@ -43,7 +43,7 @@ extern "C" {
 #include <sys/file.h>
 #include <stddef.h>
 
-#define DISORDERFS_VERSION "0.5.4"
+#define DISORDERFS_VERSION "0.5.5"
 
 namespace {
 	std::vector<std::string>	bare_arguments;
@@ -293,6 +293,12 @@ int	main (int argc, char** argv)
 	 * Initialize disorderfs_fuse_operations
 	 */
 
+	/*
+	 * Indicate that we should accept UTIME_OMIT (and UTIME_NOW) in the
+	 * utimens operations for "touch -m" and "touch -a"
+	 */
+	disorderfs_fuse_operations.flag_utime_omit_ok = 1;
+
 	disorderfs_fuse_operations.getattr = [] (const char* path, struct stat* st) -> int {
 		Guard g;
 		if (lstat((root + path).c_str(), st) == -1) {
